local K = {}

--[[ Leader ]]
vim.g.mapleader = ' '

--[[ Indentation ]]
vim.keymap.set('n', '<Tab>', '>>')
vim.keymap.set('n', '<S-Tab>', '<<')

--[[ Groups ]]
K.GROUPS = {
    { '<leader>s', group = 'Session' },
    { '<leader>g', group = 'Git/Global' },
    { '<leader>o', group = 'Ollama' },
    { '<leader>f', group = 'File' },
    { '<leader>d', group = 'Debugger' },
    { '<leader>c', group = 'Code' },
    { '<leader>a', group = 'Angular' },
}

--[[ Focus Shade ]]
K.FOCUS_SHADE = {
    UP = {
        shortcut = '<C-Up>',
    },
    DOWN = {
        shortcut = '<C-Down>',
    },
}

--[[ Sessions ]]
K.SESSIONS = {
    CREATE = {
        mode = 'n',
        shortcut = '<leader>sc',
        description = 'Create Session',
    },
    MENU = {
        mode = 'n',
        shortcut = '<leader>sm',
        description = 'Open Session Menu',
    },
}

--[[ Git ]]
K.GIT = {
    OPEN = {
        mode = 'n',
        shortcut = '<Leader>go',
        description = 'Open Git',
    },
    HUNK = {
        mode = 'n',
        shortcut = '<Leader>gh',
        description = 'Toggle Inline Git Diff',
    },
    BLAME = {
        mode = 'n',
        shortcut = '<Leader>gb',
        description = 'Toggle Inline Git Blame',
    },
}

--[[ Terminal ]]
K.TOGGLE_TERMINAL = {
    mode = { 'n', 't' },
    shortcut = '<F6>',
    description = 'Toggle Terminal',
}

--[[ Ollam ]]
K.OLLAMA = {
    mode = 'n',
    shortcut = '<leader>op',
    description = 'Ollama Prompt',
}

--[[ Snippets ]]
K.SNIPPETS = {
    ACCEPT_OR_JUMP = {
        mode = { 'i', 's' },
        shortcut = '<Tab>',
    },
    JUMP_BACKWARDS = {
        mode = { 'i', 's' },
        shortcut = '<S-Tab>',
    },
}

--[[ Search ]]
K.SEARCH = {
    FIND_FILE = {
        mode = 'n',
        shortcut = '<leader>ff',
        description = 'Find File',
    },
    FUZZY_FIND = {
        mode = 'n',
        shortcut = '<leader>fz',
        description = 'Fuzzy File',
    },
    GLOBAL_FIND_FILE = {
        mode = 'n',
        shortcut = '<leader>gff',
        description = 'Global Find File',
    },
    GLOBAL_FUZZY_FIND = {
        mode = 'n',
        shortcut = '<leader>gfz',
        description = 'Global Fuzzy File',
    },
}

--[[ Debugging ]]
K.DEBUGGING = {
    TOGGLE_UI = {
        mode = 'n',
        shortcut = '<Leader>dt',
        description = 'Toggle Debugger UI',
    },
    TOGGLE_BREAKPOINT = {
        mode = 'n',
        shortcut = '<Leader>db',
        description = 'Toggle Breakpoint',
    },
    CONTINUE = {
        mode = 'n',
        shortcut = '<Leader>dc',
        description = 'Debugger Continue',
    },
    TERMINATE = {
        mode = 'n',
        shortcut = '<Leader>dx',
        description = 'Debugger Terminate',
    },
    STEP_OVER = {
        mode = 'n',
        shortcut = '<Leader>ds',
        description = 'Debugger Step Over',
    },
}

--[[ File Tree ]]
K.FILE_TREE = {
    TOGGLE = {
        mode = 'n',
        shortcut = '<Leader>ft',
        description = 'Toggle File Tree',
    },
    SHOW_OPEN = {
        mode = 'n',
        shortcut = '<Leader>fo',
        description = 'Show Open Files',
    },
}

--[[ CODE ]]
K.CODE = {
    SHOW_DEFINITION = {
        mode = 'n',
        shortcut = '<Leader>cd',
        description = 'Show Code Definition',
    },
    GOTO_DEFINITION = {
        mode = 'n',
        shortcut = '<Leader>cg',
        description = 'Go to Definition',
    },
    PEEK_DEFINITION = {
        mode = 'n',
        shortcut = '<Leader>cp',
        description = 'Peek Code Definition',
    },
    GOTO_REFERENCES = {
        mode = 'n',
        shortcut = '<Leader>cr',
        description = 'Go to References',
    },
    ACTIONS = {
        mode = 'n',
        shortcut = '<Leader>ca',
        description = 'Do Code Actions',
    },
    ERROR = {
        mode = 'n',
        shortcut = '<leader>ce',
        description = 'Show Code Errors',
    },
    FORMAT = {
        mode = 'n',
        shortcut = '<Leader>cf',
        description = 'Format Code',
    },
    RENAME = {
        mode = 'n',
        shortcut = '<Leader>cn',
        description = 'Rename Variable',
    },
}

--[[ Angular ]]
K.ANGULAR = {
    TEMPLATE = {
        mode = 'n',
        shortcut = '<Leader>at',
        description = 'Go to Angular Template',
    },
    COMPONENT = {
        mode = 'n',
        shortcut = '<Leader>ac',
        description = 'Go to Angular Component',
    },
}

return K
